#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['dotenv_stripout']

package_data = \
{'': ['*']}

install_requires = \
['typer==0.3.2']

extras_require = \
{'dev': ['black==19.10b0', 'flake8==3.8.1', 'isort==4.3.21', 'pytest==6.2.4']}

entry_points = \
{'console_scripts': ['dotenv-stripout = dotenv_stripout.cli:cli']}

setup(name='dotenv-stripout',
      version='0.1.0',
      description='Strip secrets from .env files',
      author='Harrison Pim',
      author_email='hello@harrisonpim.com',
      url='https://github.com/harrisonpim/dotenv-stripout',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      extras_require=extras_require,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
